<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">供应商名称/合同号：</span>
        <el-input
            v-model="searchForm.supplierNameOrContractNo"
            style="width: 240px"
            placeholder="输入供应商名称/合同号搜索"
            @change="handleQuery"
            clearable
            :prefix-icon="Search"
        />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px">搜索</el-button>
      </div>
    </div>
    <div class="table_list">
      <PIMTable :column="tableColumn" :tableData="tableData" :page="page" :handleSelectionChange="handleSelectionChange"
                :tableLoading="tableLoading" @pagination="pagination" :total="total"></PIMTable>
    </div>
    <el-dialog v-model="dialogFormVisible" :title="operationType === 'add' ? '新增付款登记' : '编辑付款登记'" width="60%" @close="closeDia">
      <el-form :model="form" label-width="140px" label-position="top" :rules="rules" ref="formRef">
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="采购合同号：" prop="purchaseLedgerId">
              <el-select v-model="form.purchaseLedgerId" placeholder="请选择" clearable @change="setInfo" :disabled="operationType === 'edit'">
                <el-option v-for="item in purchaseLedgerList" :key="item.id" :label="item.purchaseContractNumber" :value="item.id"/>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="销售合同号：" prop="salesContractNo">
              <el-input v-model="form.salesContractNo" placeholder="自动填充" clearable disabled/>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="供应商名称：" prop="supplierName">
              <el-input v-model="form.supplierName" placeholder="自动填充" clearable disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="发票号：" prop="invoiceNumber">
              <el-select v-model="form.invoiceNumber" placeholder="请选择" clearable :disabled="operationType === 'edit'" @change="setInvoiceAmount">
                <el-option v-for="item in invoiceNumberList" :key="item.id" :label="item.invoiceNumber" :value="item.invoiceNumber"/>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="发票金额(元)：" prop="invoiceAmount">
              <el-input type="number" :step="0.01" v-model="form.invoiceAmount" placeholder="自动填充" clearable disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="税率(%)：" prop="taxRate">
               <el-select v-model="form.taxRate"  placeholder="请选择" clearable :disabled="operationType === 'edit'">
                <el-option v-for="item in taxRateSelection" :key="item.value" :label="item.label" :value="item.value"/>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="本次付款金额：" prop="currentPaymentAmount">
              <el-input type="number" :step="0.01" v-model="form.currentPaymentAmount" placeholder="请输入" clearable/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="付款形式：" prop="paymentMethod">
              <el-select v-model="form.paymentMethod" placeholder="请选择" clearable>
                <el-option label="电汇" value="电汇"/>
                <el-option label="承兑" value="承兑"/>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="30">
          <el-col :span="12">
            <el-form-item label="登记人：" prop="registrant">
              <el-input v-model="form.registrant" placeholder="请输入" clearable disabled/>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="付款日期：" prop="paymentDate">
              <el-date-picker
                  disabled
                  style="width: 100%"
                  v-model="form.paymentDate"
                  value-format="YYYY-MM-DD"
                  format="YYYY-MM-DD"
                  type="date"
                  placeholder="请选择"
                  clearable
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确认</el-button>
          <el-button @click="closeDia">取消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref } from 'vue'
import {Search} from "@element-plus/icons-vue";
import {
  registrationList,
} from "@/api/procurementManagement/paymentEntry.js";
const tableColumn = ref([
  {
    label: '付款日期',
    prop: 'paymentDate',
  },
  {
    label: '供应商名称',
    prop: 'supplierName',
  },
  {
    label: '付款金额',
    prop: 'currentPaymentAmount',
  },
  {
    label: '登记人',
    prop: 'registrant'
  },
  {
    label: '登记日期',
    prop: 'registrationtDate'
  },
])
const tableData = ref([])
const tableLoading = ref(false)
const purchaseLedgerList = ref([])
const invoiceNumberList = ref([])
const page = reactive({
  current: 1,
  size: 10,
})
const total = ref(0)

// 用户信息表单弹框数据
const operationType = ref('')
const dialogFormVisible = ref(false)
const data = reactive({
  searchForm: {
    supplierNameOrContractNo: '',
  },
})
const { searchForm, form, rules } = toRefs(data)

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1
  getList()
}
const pagination = ({ current, limit }) => {
  page.current = current;
  page.size = limit;
  getList()
}
const getList = () => {
  tableLoading.value = true
  registrationList({...searchForm.value, ...page}).then(res => {
    tableLoading.value = false
    tableData.value = res.rows
    total.value = res.total
  })
}
getList()
</script>

<style scoped lang="scss">

</style>
